from setuptools import setup

setup(
    name ="stats_estimator",
    version = "0.0.5",
    description = " Files to get values of gaussian and binomial distribution",
    packages = ["stats_estimator"],
    author= "irahul",
    zip_safe= False 
)